@@ -94,10 +94,16 @@ class Artifact(object):
 
     @classmethod
     def retrieve(klass, hashstring):
-        artifact = klass()
-        artifact.hashstring = hashstring
-        artifact.load()
-        return artifact
+        if not hasattr(klass, 'retrieved_artifacts'):
+            klass.retrieved_artifacts = {}
+        if klass.retrieved_artifacts.has_key(hashstring):
+            return klass.retrieved_artifacts[hashstring]
+        else:
+            artifact = klass()
+            artifact.hashstring = hashstring
+            artifact.load()
+            klass.retrieved_artifacts[hashstring] = artifact
+            return artifact
 
     def load(self):
         self.load_meta()
