@@ -1,8 +1,8 @@
+from dexy.dexy_filter import DexyFilter
 from ordereddict import OrderedDict
-from dexy.handler import DexyHandler
 from pynliner import Pynliner
 
-class PynlinerHandler(DexyHandler):
+class PynlinerHandler(DexyFilter):
     """
     Move CSS inline, for posting to web without a stylesheet or for emailing.
     For now hard-coded to look for a pastie.css file in project root.
@@ -19,7 +19,7 @@ class PynlinerHandler(DexyHandler):
             try:
                 p = Pynliner(self.log)
             except TypeError:
-                print "the pynliner filter says: please upgrade to the latest version of pynliner (e.g. easy_install -U pynliner)"
+                print "the pynliner filter says: please install pynliner from source (https://github.com/rennat/pynliner.git) or version > 0.2.1"
                 p = Pynliner()
             p.from_string(v).with_cssString(css)
             output_dict[k] = p.run()
